@@ -1,11 +1,17 @@
 module Hint.GHC (
-    Message, module X
+    Message, module X,
+#if __GLASGOW_HASKELL__ < 804
+    GhcPs, mgModSummaries
+#endif
 ) where
 
 import GHC as X hiding (Phase, GhcT, runGhcT)
 import Control.Monad.Ghc as X (GhcT, runGhcT)
 
 import HscTypes as X (SourceError, srcErrorMessages, GhcApiError)
+#if __GLASGOW_HASKELL__ >= 804
+import HscTypes as X (mgModSummaries)
+#endif
 
 import Outputable as X (PprStyle, SDoc, Outputable(ppr),
                         showSDoc, showSDocForUser, showSDocUnqual,
@@ -19,15 +25,9 @@ import Lexer as X (P(..), ParseResult(..), mkPState)
 import Parser as X (parseStmt, parseType)
 import FastString as X (fsLit)
 
-#if __GLASGOW_HASKELL__ >= 710
 import DynFlags as X (xFlags, xopt, LogAction, FlagSpec(..))
-#else
-import DynFlags as X (xFlags, xopt, LogAction)
-#endif
 
-#if __GLASGOW_HASKELL__ >= 800
 import DynFlags as X (WarnReason(NoReason))
-#endif
 
 import PprTyThing as X (pprTypeForUser)
 import SrcLoc as X (mkRealSrcLoc)
@@ -37,3 +37,10 @@ import ConLike as X (ConLike(RealDataCon))
 import DynFlags as X (addWay', Way(..), dynamicGhc)
 
 type Message = MsgDoc
+
+#if __GLASGOW_HASKELL__ < 804
+type GhcPs = RdrName
+
+mgModSummaries :: ModuleGraph -> [ModSummary]
+mgModSummaries = id
+#endif
